@@ -1,13 +1,11 @@
 /***************************************************************************
- $RCSfile: jobgetbalance_p.h,v $
- -------------------
- cvs         : $Id: jobgetbalance_p.h,v 1.1 2004/08/18 16:32:00 aquamaniac Exp $
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2013 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -25,7 +23,7 @@ typedef struct AB_JOBGETBALANCE AB_JOBGETBALANCE;
 struct AB_JOBGETBALANCE {
   AB_ACCOUNT_STATUS *accountStatus;
 };
-void AB_JobGetBalance_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AB_JobGetBalance_FreeData(void *bp, void *p);
 
 
 #ifdef __cplusplus
