@@ -139,10 +139,7 @@ int AH_Job_GetTransactions__ReadTransactions(AH_JOB *j,
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Plugin SWIFT is not found");
     GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
-			 I18N("Plugin \"SWIFT\" not found.\n"
-			      "If you are using Debian/Ubuntu then you are "
-			      "probably missing the package "
-			      "\"libaqbanking-plugins-libgwenhywfar\""));
+			 I18N("Plugin \"SWIFT\" not found."));
     return AB_ERROR_PLUGIN_MISSING;
   }
 
@@ -170,10 +167,12 @@ int AH_Job_GetTransactions__ReadTransactions(AH_JOB *j,
     GWEN_DB_Group_free(dbParams);
     GWEN_DB_Group_free(db);
     GWEN_SyncIo_free(sio);
+    GWEN_DBIO_free(dbio);
     return rv;
   }
   GWEN_DB_Group_free(dbParams);
   GWEN_SyncIo_free(sio);
+  GWEN_DBIO_free(dbio);
 
   /* first count the groups */
   dbDay=GWEN_DB_FindFirstGroup(db, "day");
