@@ -277,6 +277,7 @@ void AH_Outbox__CBox_Finish(AH_OUTBOX__CBOX *cbox){
       AH_Job_List_Del(j);
       AH_Job_List_Add(j, cbox->finishedJobs);
     } /* while */
+    AH_Job_List_free(jl);
     AH_JobQueue_free(jq);
   } /* while */
 
@@ -292,6 +293,7 @@ void AH_Outbox__CBox_Finish(AH_OUTBOX__CBOX *cbox){
       AH_Job_List_Del(j);
       AH_Job_List_Add(j, cbox->finishedJobs);
     } /* while */
+    AH_Job_List_free(jl);
     AH_JobQueue_free(jq);
   } /* while */
 
@@ -627,8 +629,6 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
 	AH_Job_List_Add(j, cbox->todoJobs);
 	j=jnext;
       }
-      AH_Job_List_free(retryJobs);
-      retryJobs=0;
 
       /* there are some retry jobs, retry them */
       if (AH_JobQueue_GetCount(jq)!=0) {
@@ -638,6 +638,8 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
 	queueCreated=1;
       }
     }
+    AH_Job_List_free(retryJobs);
+    retryJobs=NULL;
 
     /* check whether we could do something in the last loop */
     if (!jobsAdded && !queueCreated) {
@@ -708,6 +710,7 @@ int AH_Outbox__CBox_SendQueue(AH_OUTBOX__CBOX *cbox,
 		       I18N("Sending queue"));
 
   rv=AH_Dialog_SendMessage(dlg, msg);
+  AH_Msg_free(msg);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not send message");
     GWEN_Gui_ProgressLog(0,
@@ -1029,6 +1032,7 @@ void AH_Outbox__CBox_HandleQueueError(AH_OUTBOX__CBOX *cbox,
     }
     AH_Job_List_Add(j, cbox->finishedJobs);
   }
+  AH_Job_List_free(jl);
   AH_JobQueue_free(jq);
 }
 
@@ -1037,12 +1041,11 @@ void AH_Outbox__CBox_HandleQueueError(AH_OUTBOX__CBOX *cbox,
 int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
 				 AH_DIALOG *dlg,
 				 AH_JOBQUEUE *jq) {
-  int jobsTodo;
   int rv;
 
-  jobsTodo=0;
   for (;;) {
     AH_JOBQUEUE *jqTodo;
+    int jobsTodo;
     uint32_t jqFlags;
     AH_JOB *j;
     AH_JOB_LIST *jl;
@@ -1062,10 +1065,8 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
     /* copy todo jobs */
     while((j=AH_Job_List_First(jl))) {
       AH_Job_List_Del(j);
-      /* prepare jobs for next message
-       * (if attachpoint or multi-message job)
-       */
       if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
+        DBG_DEBUG(AQHBCI_LOGDOMAIN, "Message finished");
 	/* prepare job for next message
 	 * (if attachpoint or multi-message job)
 	 */
@@ -1108,9 +1109,6 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
 	  j=0; /* mark that this job has been dealt with */
 	}
       }
-      else if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
-        DBG_DEBUG(AQHBCI_LOGDOMAIN, "Message finished");
-      }
       else {
 	DBG_DEBUG(AQHBCI_LOGDOMAIN, "Bad status \"%s\" (%d)",
 		  AH_Job_StatusName(AH_Job_GetStatus(j)),
@@ -1124,6 +1122,7 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
       }
     } /* while */
 
+    AH_Job_List_free(jl);
     AH_JobQueue_free(jq);
     jq=jqTodo;
 
@@ -1172,7 +1171,6 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
       AH_Dialog_free(dlg);
       return rv;
     }
-    assert(dlg);
   
     jq=AH_JobQueue_List_First(jql);
     jqflags=AH_JobQueue_GetFlags(jq);
@@ -1192,6 +1190,7 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
     }
     else if (rv==1) {
       AH_Dialog_Disconnect(dlg);
+      AH_Dialog_free(dlg);
       GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Info,
 			   I18N("Retrying to open dialog"));
@@ -1262,7 +1261,6 @@ int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
     AH_Dialog_free(dlg);
     return rv;
   }
-  assert(dlg);
 
   /* select iTAN mode */
   if (!(AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_NOITAN)) {
@@ -1347,6 +1345,7 @@ int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox) {
 
     /* there are matching queues, handle them */
     while((jq=AH_JobQueue_List_First(jqlWanted))) {
+      AH_JobQueue_List_Del(jq);
       rv=AH_Outbox__CBox_PerformDialogQueue(cbox, jq);
       if (rv) {
 	DBG_INFO(AQHBCI_LOGDOMAIN,
@@ -1393,8 +1392,8 @@ int AH_Outbox__CBox_SendAndRecvSelected(AH_OUTBOX__CBOX *cbox,
                                            "selected jobs");
       cbox->todoQueues=AH_JobQueue_List_new();
       return rv;
-    } /* while */
-  }
+    }
+  } /* if matching queuees */
   else
     AH_JobQueue_List_free(jqlWanted);
   return 0;
@@ -1922,7 +1921,6 @@ void AH_Outbox_Process(AH_OUTBOX *ob){
 	snprintf(buf, sizeof(buf)-1,
 		 I18N("Error processing job %s"),
 		 AH_Job_GetName(j));
-	AH_Job_SetStatus(j, AH_JobStatusError);
 
 	GWEN_Gui_ProgressLog(
 			       0,
@@ -2115,6 +2113,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
       GWEN_Gui_ProgressLog(pid,
 			   GWEN_LoggerLevel_Error,
 			   I18N("Unable to lock users"));
+      AB_User_List2_free(lockedUsers);
     }
   }
   else
@@ -2138,6 +2137,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
 			     GWEN_LoggerLevel_Error,
 			     I18N("Unable to unlock users"));
       }
+      AB_User_List2_free(lockedUsers);
       if (rv==0 && rv2!=0)
 	rv=rv2;
     }
