@@ -76,7 +76,7 @@ int AHB_SWIFT940_Parse_25(const AHB_SWIFT_TAG *tg,
     AHB_SWIFT__SetCharValue(data,
                             GWEN_DB_FLAGS_OVERWRITE_VARS,
                             "localBankCode", s);
-    free(s);
+    GWEN_Memory_dealloc(s);
     p=p2+1;
   }
 
@@ -103,7 +103,7 @@ int AHB_SWIFT940_Parse_25(const AHB_SWIFT_TAG *tg,
       AHB_SWIFT__SetCharValue(data,
                               GWEN_DB_FLAGS_OVERWRITE_VARS,
                               "localAccountNumber", s);
-      free(s);
+      GWEN_Memory_dealloc(s);
     }
   }
   return 0;
@@ -373,6 +373,7 @@ int AHB_SWIFT940_Parse_86(const AHB_SWIFT_TAG *tg,
 	} /* while */
       }
     } /* if really structured */
+    AHB_SWIFT_SubTag_List_free(stlist);
 #else
     const char *p2;
     char *s;
@@ -484,7 +485,7 @@ int AHB_SWIFT940_Parse_86(const AHB_SWIFT_TAG *tg,
         } /* switch */
       }
       p=p2;
-      free(s);
+      GWEN_Memory_dealloc(s);
     } /* while */
 #endif
   } /* if structured */
@@ -600,6 +601,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
                                           "valutadate"))) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error saving valuta date");
   }
+  GWEN_Time_free(ti);
   p+=6;
   bleft-=6;
 
@@ -638,6 +640,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
 					    "date"))) {
       DBG_ERROR(AQBANKING_LOGDOMAIN, "Error saving date");
     }
+    GWEN_Time_free(ti);
     p+=4;
     bleft-=4;
   }
@@ -702,7 +705,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
   if (currency)
     AHB_SWIFT__SetCharValue(data, flags,
 			    "value/currency", currency);
-  free(s);
+  GWEN_Memory_dealloc(s);
   bleft-=p2-p;
   p=p2;
 
@@ -747,7 +750,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
       s[p2-p]=0;
       if (strcasecmp(s, "NONREF")!=0)
         AHB_SWIFT__SetCharValue(data, flags, "customerReference", s);
-      free(s);
+      GWEN_Memory_dealloc(s);
     }
     bleft-=p2-p;
     p=p2;
@@ -773,7 +776,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
       memmove(s, p, p2-p+1);
       s[p2-p]=0;
       AHB_SWIFT__SetCharValue(data, flags, "bankReference", s);
-      free(s);
+      GWEN_Memory_dealloc(s);
       bleft-=p2-p;
       p=p2;
       assert(bleft>=0);
@@ -824,7 +827,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
           memmove(s, p, p2-p+1);
           s[p2-p]=0;
           AHB_SWIFT__SetCharValue(data, flags, "origvalue/value", s);
-          free(s);
+          GWEN_Memory_dealloc(s);
           bleft-=p2-p;
           p=p2;
         }
@@ -855,7 +858,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
           memmove(s, p, p2-p+1);
           s[p2-p]=0;
           AHB_SWIFT__SetCharValue(data, flags, "charges/value", s);
-          free(s);
+          GWEN_Memory_dealloc(s);
           bleft-=p2-p;
           p=p2;
         }
@@ -929,6 +932,7 @@ int AHB_SWIFT940_Parse_6_0_2(const AHB_SWIFT_TAG *tg,
 					  "date"))) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error saving date");
   }
+  GWEN_Time_free(ti);
 
   p+=6;
   bleft-=6;
@@ -977,7 +981,7 @@ int AHB_SWIFT940_Parse_6_0_2(const AHB_SWIFT_TAG *tg,
     s[p2-p]=0;
   }
   AHB_SWIFT__SetCharValue(data, flags, "value/value", s);
-  free(s);
+  GWEN_Memory_dealloc(s);
   bleft-=p2-p;
   p=p2;
 
@@ -1078,7 +1082,7 @@ int AHB_SWIFT940_Parse_NS(const AHB_SWIFT_TAG *tg,
 		   AHB_SWIFT_Tag_GetData(tg));
 	  break;
 	}
-        free(s);
+        GWEN_Memory_dealloc(s);
       }
       p=p2;
     }
