@@ -37,7 +37,6 @@ int transfer(AB_BANKING *ab,
   GWEN_DB_NODE *db;
   int rv;
   const char *ctxFile;
-  const char *country;
   const char *bankId;
   const char *accountId;
   const char *subAccountId;
@@ -49,7 +48,6 @@ int transfer(AB_BANKING *ab,
   AB_JOB_LIST2 *jobList;
   AB_JOB *j;
   int rvExec;
-  const char *rCountry;
   const char *rBankId;
   const char *rAccountId;
   int forceCheck;
@@ -110,17 +108,6 @@ int transfer(AB_BANKING *ab,
     "Specify the sub account id (Unterkontomerkmal)",    /* short description */
     "Specify the sub account id (Unterkontomerkmal)"     /* long description */
   },
-  {
-    GWEN_ARGS_FLAGS_HAS_ARGUMENT,  /* flags */
-    GWEN_ArgsType_Char,             /* type */
-    "remoteCountry",               /* name */
-    0,                             /* minnum */
-    1,                             /* maxnum */
-    0,                             /* short option */
-    "rcountry",                    /* long option */
-    "Specify the remote country code",/* short description */
-    "Specify the remote country code" /* long description */
-  },
   {
     GWEN_ARGS_FLAGS_HAS_ARGUMENT,  /* flags */
     GWEN_ArgsType_Char,             /* type */
@@ -255,7 +242,7 @@ int transfer(AB_BANKING *ab,
   },
   {
     GWEN_ARGS_FLAGS_HAS_ARGUMENT,                
-    GWEN_ArgsType_Int,
+    GWEN_ArgsType_Char,
     "executionPeriod", 
     0,  
     1,  
@@ -299,7 +286,6 @@ int transfer(AB_BANKING *ab,
     return 0;
   }
 
-  country=GWEN_DB_GetCharValue(db, "country", 0, "de");
   bankId=GWEN_DB_GetCharValue(db, "bankId", 0, 0);
   accountId=GWEN_DB_GetCharValue(db, "accountId", 0, 0);
   subAccountId=GWEN_DB_GetCharValue(db, "subAccountId", 0, 0);
@@ -320,19 +306,17 @@ int transfer(AB_BANKING *ab,
 
   /* get account */
   al=AB_Banking_FindAccounts(ab, "*", "*", bankId, accountId, subAccountId);
-  if (AB_Account_List2_GetSize(al)==0) {
+  if (al==NULL || AB_Account_List2_GetSize(al)==0) {
     DBG_ERROR(0, "Account not found");
     return 2;
   }
   else if (AB_Account_List2_GetSize(al)>1) {
     DBG_ERROR(0, "Ambiguous account specification");
+    AB_Account_List2_free(al);
     return 2;
   }
   a=AB_Account_List2_GetFront(al);
-  //AB_Account_List2_free(al);
-
-  /* populate job list */
-  jobList=AB_Job_List2_new();
+  AB_Account_List2_free(al);
 
   /* create transaction from arguments */
   t=mkTransfer(a, db, &transferType);
@@ -344,13 +328,10 @@ int transfer(AB_BANKING *ab,
   if (AB_Transaction_GetTextKey(t)==0)
     AB_Transaction_SetTextKey(t, 51);
 
-  rCountry=AB_Transaction_GetRemoteCountry(t);
-  if (rCountry==NULL)
-    rCountry=country;
   rBankId=AB_Transaction_GetRemoteBankCode(t);
   rAccountId=AB_Transaction_GetRemoteAccountNumber(t);
   res=AB_Banking_CheckAccount(ab,
-			      rCountry,
+			      "de",
 			      0,
 			      rBankId,
 			      rAccountId);
@@ -360,12 +341,14 @@ int transfer(AB_BANKING *ab,
 	      "Invalid combination of bank code and account number "
 	      "for remote account (%s/%s)",
 	      rBankId, rAccountId);
+    AB_Transaction_free(t);
     return 3;
 
   case AB_BankInfoCheckResult_UnknownBank:
     DBG_ERROR(0, "Remote bank code is unknown (%s/%s)",
 	      rBankId, rAccountId);
     if (forceCheck) {
+      AB_Transaction_free(t);
       return 4;
     }
     break;
@@ -381,6 +364,7 @@ int transfer(AB_BANKING *ab,
 
   default:
     DBG_ERROR(0, "Unknown check result %d", res);
+    AB_Transaction_free(t);
     return 4;
   }
 
@@ -392,22 +376,29 @@ int transfer(AB_BANKING *ab,
     j=AB_JobCreateStandingOrder_new(a);
   else {
     DBG_ERROR(0, "Unknown transfer type: %d", transferType);
+    AB_Transaction_free(t);
     return 6;
   }
 
   rv=AB_Job_CheckAvailability(j);
   if (rv<0) {
     DBG_ERROR(0, "Job not supported.");
-    AB_ImExporterContext_free(ctx);
+    AB_Job_free(j);
+    AB_Transaction_free(t);
     return 3;
   }
 
   rv=AB_Job_SetTransaction(j, t);
+  AB_Transaction_free(t);
   if (rv<0) {
     DBG_ERROR(0, "Unable to add transaction");
-    AB_ImExporterContext_free(ctx);
+    AB_Job_free(j);
     return 3;
   }
+
+  /* populate job list */
+  jobList=AB_Job_List2_new();
+  assert(jobList);
   AB_Job_List2_PushBack(jobList, j);
 
   /* execute job */
@@ -418,9 +409,11 @@ int transfer(AB_BANKING *ab,
     fprintf(stderr, "Error on executeQueue (%d)\n", rv);
     rvExec=3;
   }
+  AB_Job_List2_FreeAll(jobList);
 
   /* write result */
   rv=writeContext(ctxFile, ctx);
+  AB_ImExporterContext_free(ctx);
   if (rv<0) {
     DBG_ERROR(0, "Error writing context file (%d)", rv);
     AB_Banking_OnlineFini(ab);
