@@ -88,12 +88,6 @@ int writeContext(const char *ctxFile, const AB_IMEXPORTER_CONTEXT *ctx) {
   GWEN_SYNCIO *sio;
   int rv;
 
-  dbCtx=GWEN_DB_Group_new("context");
-  rv=AB_ImExporterContext_toDb(ctx, dbCtx);
-  if (rv<0) {
-    DBG_ERROR(0, "Error writing context to db");
-    return rv;
-  }
   if (ctxFile==NULL) {
     sio=GWEN_SyncIo_File_fromStdout();
     GWEN_SyncIo_AddFlags(sio,
@@ -132,15 +126,15 @@ int writeContext(const char *ctxFile, const AB_IMEXPORTER_CONTEXT *ctx) {
   rv=GWEN_DB_WriteToIo(dbCtx, sio, GWEN_DB_FLAGS_DEFAULT);
   if (rv<0) {
     DBG_ERROR(0, "Error writing context (%d)", rv);
-    GWEN_DB_Group_free(dbCtx);
-    GWEN_SyncIo_Disconnect(sio);
-    GWEN_SyncIo_free(sio);
-    return rv;
   }
+  else
+    rv=0;
 
   GWEN_DB_Group_free(dbCtx);
+  GWEN_SyncIo_Disconnect(sio);
+  GWEN_SyncIo_free(sio);
 
-  return 0;
+  return rv;
 }
 
 
@@ -149,8 +143,9 @@ AB_TRANSACTION *mkTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int *transferType) {
   AB_BANKING *ab;
   AB_TRANSACTION *t;
   const char *s;
-  int period, i;
+  int i;
   GWEN_TIME *d;
+  AB_TRANSACTION_PERIOD period=AB_Transaction_PeriodUnknown;
 
   *transferType = 0; // single transfer
   assert(a);
@@ -252,9 +247,11 @@ AB_TRANSACTION *mkTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int *transferType) {
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return 0;
     }
     AB_Transaction_SetDate(t, d);
+    GWEN_Time_free(d);
     *transferType = 1;
     return t;
   }
@@ -272,9 +269,11 @@ AB_TRANSACTION *mkTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int *transferType) {
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid first execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return 0;
     }
     AB_Transaction_SetFirstExecutionDate(t, d);
+    GWEN_Time_free(d);
   } else
     return t; // single transfer
 
@@ -291,29 +290,38 @@ AB_TRANSACTION *mkTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int *transferType) {
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid last execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return 0;
     }
     AB_Transaction_SetLastExecutionDate(t, d);
+    GWEN_Time_free(d);
   }
 
-  period=i=GWEN_DB_GetIntValue(db, "executionPeriod", 0, 0);
-  if (i <= 0 || i > 2) {
-    DBG_ERROR(0, "Invalid execution period value \"%d\"", i);
-    return 0;
+  s=GWEN_DB_GetCharValue(db, "executionPeriod", 0, 0);
+  if (s && *s) {
+    period=AB_Transaction_Period_fromString(s);
+    if (period==AB_Transaction_PeriodUnknown) {
+      DBG_ERROR(0, "Invalid execution period value \"%s\"", s);
+      AB_Transaction_free(t);
+      return NULL;
+    }
+    AB_Transaction_SetPeriod(t, period);
   }
-  if (i == 1) AB_Transaction_SetPeriod(t, AB_Transaction_PeriodWeekly);
-  else AB_Transaction_SetPeriod(t, AB_Transaction_PeriodMonthly);
 
-  i=GWEN_DB_GetIntValue(db, "executionCycle", 0, 1);
+  i=GWEN_DB_GetIntValue(db, "executionCycle", 0, -1);
   if (i <= 0) {
     DBG_ERROR(0, "Invalid execution cycle value \"%d\"", i);
+    AB_Transaction_free(t);
     return 0;
   }
   AB_Transaction_SetCycle(t, i);
 
-  i=GWEN_DB_GetIntValue(db, "executionDay", 0, 1);
-  if (i <= 0 || (period == 1 && i > 7) || (period == 2 && i > 30)) {
+  i=GWEN_DB_GetIntValue(db, "executionDay", 0, -1);
+  if (i <= 0 || (period == AB_Transaction_PeriodWeekly && i > 7) ||
+      (period == AB_Transaction_PeriodMonthly && i > 30 &&
+       (i < 97 || i > 99))) {
     DBG_ERROR(0, "Invalid execution day value \"%d\"", i);
+    AB_Transaction_free(t);
     return 0;
   }
   AB_Transaction_SetExecutionDay(t, i);
@@ -434,9 +442,11 @@ AB_TRANSACTION *mkSepaTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int expTransferT
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return NULL;
     }
     AB_Transaction_SetDate(t, d);
+    GWEN_Time_free(d);
   }
 
   /* standing orders */
@@ -452,9 +462,11 @@ AB_TRANSACTION *mkSepaTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int expTransferT
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid first execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return NULL;
     }
     AB_Transaction_SetFirstExecutionDate(t, d);
+    GWEN_Time_free(d);
   }
 
   s=GWEN_DB_GetCharValue(db, "lastExecutionDate", 0, 0);
@@ -469,9 +481,11 @@ AB_TRANSACTION *mkSepaTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int expTransferT
     GWEN_Buffer_free(dbuf);
     if (d==0) {
       DBG_ERROR(0, "Invalid last execution date value \"%s\"", s);
+      AB_Transaction_free(t);
       return NULL;
     }
     AB_Transaction_SetLastExecutionDate(t, d);
+    GWEN_Time_free(d);
   }
 
   if (expTransferType==AB_Job_TypeSepaCreateStandingOrder ||
@@ -485,6 +499,7 @@ AB_TRANSACTION *mkSepaTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int expTransferT
       period=AB_Transaction_Period_fromString(s);
       if (period==AB_Transaction_PeriodUnknown) {
         DBG_ERROR(0, "Invalid execution period value \"%s\"", s);
+        AB_Transaction_free(t);
         return NULL;
       }
     }
@@ -494,16 +509,20 @@ AB_TRANSACTION *mkSepaTransfer(AB_ACCOUNT *a, GWEN_DB_NODE *db, int expTransferT
     }
     AB_Transaction_SetPeriod(t, period);
 
-    i=GWEN_DB_GetIntValue(db, "executionCycle", 0, 1);
+    i=GWEN_DB_GetIntValue(db, "executionCycle", 0, -1);
     if (i <= 0) {
       DBG_ERROR(0, "Invalid execution cycle value \"%d\"", i);
+      AB_Transaction_free(t);
       return NULL;
     }
     AB_Transaction_SetCycle(t, i);
 
-    i=GWEN_DB_GetIntValue(db, "executionDay", 0, 1);
-    if (i <= 0 || (period == 1 && i > 7) || (period == 2 && i > 30)) {
+    i=GWEN_DB_GetIntValue(db, "executionDay", 0, -1);
+    if (i <= 0 || (period == AB_Transaction_PeriodWeekly && i > 7) ||
+        (period == AB_Transaction_PeriodMonthly && i > 30 &&
+         (i < 97 || i > 99))) {
       DBG_ERROR(0, "Invalid execution day value \"%d\"", i);
+      AB_Transaction_free(t);
       return NULL;
     }
     AB_Transaction_SetExecutionDay(t, i);
@@ -576,7 +595,6 @@ AB_TRANSACTION *mkSepaDebitNote(AB_ACCOUNT *a, GWEN_DB_NODE *db) {
   else
     AB_Transaction_SetSequenceType(t, AB_Transaction_SequenceTypeOnce);
 
-
   return t;
 }
 
